##  Flexible Drill-Down
Drill-downs can be detached from the inventory to make them flexible for editing and customizing their contents. To detach a drill-down, select the drill-down and click Detach on the right side pane.
Once you detach a drill-down, a small icon appears in the bottom-right corner of the shape, indicating that it is no longer linked to its original context.
Identifying Detached Drill-Downs
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof26eb24d445e4e31b52f30a168913a3e_LowRes.png)
You can use flexible drill-down to:
  * Add or remove fact sheets from the drill-down container
  * Insert related fact sheets through additional drill-downs and roll-ups
  * Add any shapes or icons and link them to fact sheets
  * Remove all content inside the container to revert it back to a fact sheet


![Flexible Drill-downs](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274aaf657a4410149fd9983cf262731b_LowRes.gif)
Flexible Drill-downs
Though it is detached from the inventory, changes in fact sheet color, label, or archiving of fact sheets still trigger the 'check for updates' icons inside the flexible drill-down containers, and archived fact sheets are removed from the flexible drill-downs. However, if new relations are created in the inventory, it doesn't trigger an update in the flexible drill-down. To learn more about updates, see [Inventory Updates](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__updates_from_inventory).
